pub struct AggregationSettings {
pub aggregation_time_period: AggregationTimePeriod,
}Expand description
AggregationSettings : A container that holds all of the necessary properties to configure the aggregation of notifications.
Fields
aggregation_time_period: AggregationTimePeriodImplementations
sourceimpl AggregationSettings
impl AggregationSettings
sourcepub fn new(
aggregation_time_period: AggregationTimePeriod
) -> AggregationSettings
pub fn new(
aggregation_time_period: AggregationTimePeriod
) -> AggregationSettings
A container that holds all of the necessary properties to configure the aggregation of notifications.